@@ -10,7 +10,6 @@ import claripy
 from claripy import operations
 from claripy.ast.base import _make_name
 from claripy.errors import BackendError, ClaripyValueError
-from claripy.util import deprecated
 
 from .bits import Bits
 from .bool import Bool, If
@@ -415,8 +414,8 @@ BV.__floordiv__ = operations.op(
     "__floordiv__", (BV, BV), BV, extra_check=operations.length_same_check, calc_length=operations.basic_length_calc
 )
 BV.__rfloordiv__ = operations.reversed_op(BV.__floordiv__)
-BV.__truediv__ = deprecated("BV.__floordiv__", "BV.__truediv__")(BV.__floordiv__)
-BV.__rtruediv__ = deprecated("BV.__rfloordiv__", "BV.__rtruediv__")(BV.__rfloordiv__)
+BV.__truediv__ = BV.__floordiv__
+BV.__rtruediv__ = BV.__rfloordiv__
 BV.__mul__ = operations.op(
     "__mul__", (BV, BV), BV, extra_check=operations.length_same_check, calc_length=operations.basic_length_calc
 )
