@@ -4,7 +4,7 @@ from .backend_vsa import BackendVSA
 from .balancer import Balancer
 from .bool_result import BoolResult, FalseResult, MaybeResult, TrueResult
 from .discrete_strided_interval_set import DEFAULT_MAX_CARDINALITY_WITHOUT_COLLAPSING, DiscreteStridedIntervalSet
-from .strided_interval import CreateStridedInterval, StridedInterval
+from .strided_interval import StridedInterval
 from .valueset import ValueSet
 
 __all__ = (
@@ -12,7 +12,6 @@ __all__ = (
     "BackendVSA",
     "Balancer",
     "BoolResult",
-    "CreateStridedInterval",
     "DiscreteStridedIntervalSet",
     "FalseResult",
     "MaybeResult",
