@@ -198,13 +198,29 @@ def eq_simplifier(a, b):
     if a.op == "__sub__" and len(a.args) == 2 and a.args[1].op == "BVV" and b.op == "BVV":
         return a.args[0] == a.args[1] + b
 
-    # 1 ^ expr == 0     ->   expr == 1
     if a.op == "__xor__" and b.op == "BVV" and b.args[0] == 0 and len(a.args) == 2:
+        # 1 ^ expr == 0     ->   expr == 1
         if a.args[1].op == "BVV" and a.args[1].args[0] == 1:  # expr ^ 1 == 0
             return a.args[0] == 1
         if a.args[0].op == "BVV" and a.args[0].args[0] == 1:  # 1 ^ expr == 0
             return a.args[1] == 1
 
+        # (expr & a) ^ a == 0  ->  expr & a != 0
+        if (
+            a.args[1].op == "BVV"
+            and a.args[0].op == "__and__"
+            and a.args[0].args[1].op == "BVV"
+            and a.args[0].args[1].args[0] == a.args[1].args[0]
+        ):
+            return a.args[0] != 0
+        if (
+            a.args[1].op == "BVV"
+            and a.args[0].op == "__and__"
+            and a.args[0].args[0].op == "BVV"
+            and a.args[0].args[0].args[0] == a.args[1].args[0]
+        ):
+            return a.args[0].args[1] & a.args[0].args[0] != 0
+
     # TODO: all these ==/!= might really slow things down...
     if a.op == "If":
         if a.args[1] is b and claripy.is_true(a.args[2] != b):
@@ -280,13 +296,29 @@ def ne_simplifier(a, b):
             # (y == If(c, x, y)) -> !c
             return claripy.Not(b.args[0])
 
-    # 1 ^ expr != 0     ->   expr == 0
     if a.op == "__xor__" and b.op == "BVV" and b.args[0] == 0 and len(a.args) == 2:
+        # 1 ^ expr != 0     ->   expr == 0
         if a.args[1].op == "BVV" and a.args[1].args[0] == 1:
             return a.args[0] != 1
         if a.args[0].op == "BVV" and a.args[0].args[0] == 1:
             return a.args[1] != 1
 
+        # (expr & a) ^ a != 0  ->  expr & a == 0
+        if (
+            a.args[1].op == "BVV"
+            and a.args[0].op == "__and__"
+            and a.args[0].args[1].op == "BVV"
+            and a.args[0].args[1].args[0] == a.args[1].args[0]
+        ):
+            return a.args[0] == 0
+        if (
+            a.args[1].op == "BVV"
+            and a.args[0].op == "__and__"
+            and a.args[0].args[0].op == "BVV"
+            and a.args[0].args[0].args[0] == a.args[1].args[0]
+        ):
+            return a.args[0].args[1] & a.args[0].args[0] == 0
+
     # Masking and comparing against a constant
     simp = and_mask_comparing_against_constant_simplifier(operator.__ne__, a, b)
     if simp is not None:
@@ -370,6 +402,18 @@ def boolean_and_simplifier(*args):
     if len(args) == 1:
         return args[0]
 
+    # a == 0 && a == 1  ->  False
+    if (
+        len(args) == 2
+        and args[0].op == "__eq__"
+        and args[1].op == "__eq__"
+        and args[0].args[0] is args[1].args[0]
+        and args[0].args[1].op == "BVV"
+        and args[1].args[1].op == "BVV"
+        and args[0].args[1].args[0] != args[1].args[1].args[0]
+    ):
+        return claripy.false()
+
     new_args = [None] * len(args)
     ctr = 0
     for a in args:
@@ -396,7 +440,7 @@ def boolean_and_simplifier(*args):
             and len(b.args) >= 2
             and a.args[0] is b.args[0]
             and a.args[1] is b.args[1]
-            and a.op == "__ge__"
+            and a.op == "UGE"
             and b.op == "__ne__"
         ):
             return claripy.UGT(a.args[0], a.args[1])
@@ -757,14 +801,6 @@ def boolean_not_simplifier(body):
     if body.op == "UGE":
         return claripy.ULT(body.args[0], body.args[1])
 
-    if body.op == "__lt__":
-        return claripy.UGE(body.args[0], body.args[1])
-    if body.op == "__le__":
-        return claripy.UGT(body.args[0], body.args[1])
-    if body.op == "__gt__":
-        return claripy.ULE(body.args[0], body.args[1])
-    if body.op == "__ge__":
-        return claripy.ULT(body.args[0], body.args[1])
     return None
 
 
@@ -876,7 +912,9 @@ def extract_simplifier(high, low, val):
         all_args = tuple(a[high:low] for a in val.args)
         if val.op in flattenable:
             # directly create a flattened claripy
-            return next(a for a in all_args if isinstance(a, claripy.ast.Base)).make_like(val.op, all_args)
+            return next(a for a in all_args if isinstance(a, claripy.ast.Base)).make_like(
+                val.op, all_args, simplify=True
+            )
         return reduce(getattr(operator, val.op), all_args)
 
     #  (if cond then 1 else 0)[0:0]  ->  if(cond then 1[0:0] else 0[0:0])
@@ -1108,7 +1146,7 @@ def zeroext_comparing_against_simplifier(op, a, b):
         if (b_highbits == 0).is_false():
             if op is operator.__ne__:
                 return claripy.true()
-            # op is __eq__, __ge__
+            # op is __eq__, UGE
             return claripy.false()
 
     return None
@@ -1127,7 +1165,7 @@ _all_simplifiers = {
     "LShR": lshr_simplifier,
     "__eq__": eq_simplifier,
     "__ne__": ne_simplifier,
-    "__ge__": ge_simplifier,
+    "UGE": ge_simplifier,
     "__or__": bitwise_or_simplifier,
     "__and__": bitwise_and_simplifier,
     "__xor__": bitwise_xor_simplifier,
